@@ -161,6 +161,13 @@ elseif($page == 'htpasswds')
 		else
 		{
 			$pathSelect = makePathfield($userinfo['documentroot'], $userinfo['guid'], $userinfo['guid'], $settings['panel']['pathedit']);
+
+			$htpasswd_add_data = include_once dirname(__FILE__).'/lib/formfields/customer/extras/formfield.htpasswd_add.php';
+			$htpasswd_add_form = htmlform::genHTMLForm($htpasswd_add_data);
+
+			$title = $htpasswd_add_data['htpasswd_add']['title'];
+			$image = $htpasswd_add_data['htpasswd_add']['image'];
+
 			eval("echo \"" . getTemplate("extras/htpasswds_add") . "\";");
 		}
 	}
@@ -220,6 +227,13 @@ elseif($page == 'htpasswds')
 				}
 
 				$result = htmlentities_array($result);
+
+				$htpasswd_edit_data = include_once dirname(__FILE__).'/lib/formfields/customer/extras/formfield.htpasswd_edit.php';
+				$htpasswd_edit_form = htmlform::genHTMLForm($htpasswd_edit_data);
+
+				$title = $htpasswd_edit_data['htpasswd_edit']['title'];
+				$image = $htpasswd_edit_data['htpasswd_edit']['image'];
+
 				eval("echo \"" . getTemplate("extras/htpasswds_edit") . "\";");
 			}
 		}
@@ -357,6 +371,13 @@ elseif($page == 'htaccess')
 			$options_indexes = makeyesno('options_indexes', '1', '0', '0');
 			$cperlenabled = customerHasPerlEnabled($userinfo['customerid']);
 			$options_cgi = makeyesno('options_cgi', '1', '0', '0');
+
+			$htaccess_add_data = include_once dirname(__FILE__).'/lib/formfields/customer/extras/formfield.htaccess_add.php';
+			$htaccess_add_form = htmlform::genHTMLForm($htaccess_add_data);
+
+			$title = $htaccess_add_data['htaccess_add']['title'];
+			$image = $htaccess_add_data['htaccess_add']['image'];
+
 			eval("echo \"" . getTemplate("extras/htaccess_add") . "\";");
 		}
 	}
@@ -418,6 +439,13 @@ elseif($page == 'htaccess')
 				$cperlenabled = customerHasPerlEnabled($userinfo['customerid']);
 				$options_cgi = makeyesno('options_cgi', '1', '0', $result['options_cgi']);
 				$result = htmlentities_array($result);
+
+				$htaccess_edit_data = include_once dirname(__FILE__).'/lib/formfields/customer/extras/formfield.htaccess_edit.php';
+				$htaccess_edit_form = htmlform::genHTMLForm($htaccess_edit_data);
+	
+				$title = $htaccess_edit_data['htaccess_edit']['title'];
+				$image = $htaccess_edit_data['htaccess_edit']['image'];
+
 				eval("echo \"" . getTemplate("extras/htaccess_edit") . "\";");
 			}
 		}
