@@ -121,6 +121,8 @@ class htmlform
 				return self::_labelField($data); break;
 			case 'textarea':
 				return self::_textArea($fieldname, $data); break;
+			case 'checkbox':
+				return self::_checkbox($fieldname, $data); break;
 		}
 	}
 
@@ -148,7 +150,15 @@ class htmlform
 			$extras .= ' size="'.$data['size'].'"';
 		}
 
-		$value = isset($data['value']) ? $data['value'] : '';
+		// add support to save reloaded forms
+		if (isset($data['value'])) {
+			$value = $data['value'];
+		} elseif (isset($_SESSION['requestData'][$fieldname])) {
+			$value = $_SESSION['requestData'][$fieldname];
+		} else {
+			$value = '';
+		}
+		
 		$ulfield = ($unlimited == true ? '&nbsp;'.$data['ul_field'] : '');
 		if(isset($data['display']) && $data['display'] != '')
 		{
@@ -169,7 +179,16 @@ class htmlform
 		if(isset($data['rows'])) {
 			$extras .= ' rows="'.$data['rows'].'"';
 		}
-		$value = isset($data['value']) ? $data['value'] : '';
+		
+		// add support to save reloaded forms
+		if (isset($data['value'])) {
+			$value = $data['value'];
+		} elseif (isset($_SESSION['requestData'][$fieldname])) {
+			$value = $_SESSION['requestData'][$fieldname];
+		} else {
+			$value = '';
+		}
+		trim($value);
 
 		eval("\$return = \"" . getTemplate("misc/form/input_textarea", "1") . "\";");
 		return $return;
@@ -187,12 +206,82 @@ class htmlform
 
 	private static function _selectBox($fieldname = '', $data = array())
 	{
+		// add support to save reloaded forms
+		if (isset($data['select_var'])) {
+			$select_var = $data['select_var'];
+		} elseif (isset($_SESSION['requestData'][$fieldname])) {
+			$select_var = $_SESSION['requestData'][$fieldname];
+		} else {
+			$select_var = '';
+		}
+		
 		return '<select 
 			id="'.$fieldname.'" 
 			name="'.$fieldname.'" 
 			'.(isset($data['class']) ? ' class="'.$data['class'] .'" ' : '').'
 			>'
-			.$data['select_var'].
+			.$select_var.
 			'</select>';
 	}
+	
+	/**
+	 * Function to generate checkboxes.
+	 * 
+	 * <code>
+	 * $data = array(
+     *                       'label' => $lng['customer']['email_imap'],
+     *                       'type' => 'checkbox',
+     *                       'values' => array(
+     *                                         array(  'label' => 'active',
+     *                                                 'value' => '1'
+     *                                               )
+     *                                           ),
+     *                       'value' => array('1'),
+     *                       'mandatory' => true
+     *          )
+	 * </code>
+	 * 
+	 * @param string $fieldname contains the fieldname
+	 * @param array $data contains the data array
+	 */
+	public static function _checkbox($fieldname = '', $data = array()) {
+		// $data['value'] contains checked items
+		if (isset($data['value'])) {
+			$checked = $data['value'];
+		} else {
+			$checked = array();
+		}
+		
+		if (isset($_SESSION['requestData'])) {
+			if (isset($_SESSION['requestData'][$fieldname])) {
+				$checked[] = $_SESSION['requestData'][$fieldname];
+			}
+		}
+		
+		// default value is none, so the checkbox isn't an array
+		$isArray = '';
+		
+		if (count($data['values']) > 1) {
+			$isArray = '[]';
+		}
+		
+		// will contain the output
+		$output = "";
+		foreach($data['values'] as $val) {
+			$key = $val['label'];
+			// is this box checked?
+			$isChecked = '';
+			foreach($checked as $tmp) {
+				if ($tmp == $val['value']) {
+					$isChecked = ' checked="checked" ';
+					break;
+				}
+			}
+			
+			$output .= '<label><input type="checkbox" name="'.$fieldname.$isArray.'" value="'.$val['value'].'" '.$isChecked.'/>'.$key.'</label>';
+		}
+		
+		return $output;
+	}
+	
 }
