@@ -161,7 +161,7 @@ return array(
 						'type' => 'textul',
 						'value' => 0,
 						'maxlength' => 9,
-						'visible' => $settings['system']['mail_quota_enabled'],
+						'visible' => ($settings['system']['mail_quota_enabled'] == '1' ? true : false),
 						'mandatory' => true,
 						'ul_field' => $email_quota_ul
 					),
@@ -170,7 +170,7 @@ return array(
 						'type' => 'textul',
 						'value' => 0,
 						'maxlength' => 9,
-						'visible' => $settings['autoresponder']['autoresponder_active'],
+						'visible' => ($settings['autoresponder']['autoresponder_active'] == '1' ? true : false),
 						'ul_field' => $email_autoresponder_ul
 					),
 					'email_imap' => array(
@@ -197,7 +197,7 @@ return array(
 						'type' => 'textul',
 						'value' => 0,
 						'maxlength' => 9,
-						'visible' => $settings['ticket']['enabled'],
+						'visible' => ($settings['ticket']['enabled'] == '1' ? true : false),
 						'ul_field' => $tickets_ul
 					),
 					'mysqls' => array(
@@ -223,7 +223,7 @@ return array(
 						'type' => 'textul',
 						'value' => 0,
 						'maxlength' => 9,
-						'visible' => $settings['aps']['aps_active'],
+						'visible' => ($settings['aps']['aps_active'] == '1' ? true : false),
 						'ul_field' => $number_of_aps_packages_ul
 					)
 				)
