@@ -21,7 +21,7 @@ return array (
 	'customer' => array (
 		'index' => array (
 			'url' => 'customer_index.php',
-			'label' => $lng['menue']['main']['main'],
+			'label' => $lng['admin']['overview'],
 			'elements' => array (
 				array (
 					'label' => $lng['menue']['main']['username'],
@@ -34,6 +34,10 @@ return array (
 					'url' => 'customer_index.php?page=change_language',
 					'label' => $lng['menue']['main']['changelanguage'],
 				),
+				array (
+					'url' => 'customer_index.php?page=change_theme',
+					'label' => $lng['menue']['main']['changetheme'],
+				),
 				array (
 					'url' => 'customer_index.php?action=logout',
 					'label' => $lng['login']['logout'],
@@ -52,7 +56,7 @@ return array (
 				array (
 					'url' => 'customer_email.php?page=emails&action=add',
 					'label' => $lng['emails']['emails_add'],
-					'required_resources' => 'emails',
+					'required_resources' => 'emails'
 				),
 				array (
 					'url' => 'customer_autoresponder.php',
@@ -154,6 +158,10 @@ return array (
 					'url' => 'admin_index.php?page=change_language',
 					'label' => $lng['menue']['main']['changelanguage'],
 				),
+				array (
+					'url' => 'admin_index.php?page=change_theme',
+					'label' => $lng['menue']['main']['changetheme'],
+				),
 				array (
 					'url' => 'admin_index.php?action=logout',
 					'label' => $lng['login']['logout'],
@@ -250,4 +258,3 @@ return array (
 		),
 	),
 );
-?>
\ No newline at end of file
