@@ -767,12 +767,23 @@ class apache
 
 		if(preg_match('/^https?\:\/\//', $domain['documentroot']))
 		{
+			$corrected_docroot = $this->idnaConvert->encode($domain['documentroot']);
+			if(substr($corrected_docroot, -1) == '/') {
+				$corrected_docroot = substr($corrected_docroot, 0, -1);
+			}
+			
+			/* Get domain's redirect code */
+			$code = getDomainRedirectCode($domain['id']);
+			$modrew_red = '';
+			if ($code != '') {
+				$modrew_red = '[R='. $code . ';L]';
+			} 
+			
 			// redirect everything, not only root-directory, #541
-
 			$vhost_content.= '  <IfModule mod_rewrite.c>'."\n";
 			$vhost_content.= '    RewriteEngine On' . "\n";
 			$vhost_content.= '    RewriteCond %{HTTPS} off' . "\n";
-			$vhost_content.= '    RewriteRule (.*) '. $this->idnaConvert->encode($domain['documentroot']).'%{REQUEST_URI}'. "\n";
+			$vhost_content.= '    RewriteRule (.*) '. $corrected_docroot.'%{REQUEST_URI} ' . $modrew_red . "\n";
 			$vhost_content.= '  </IfModule>' . "\n";
 
 			$code = getDomainRedirectCode($domain['id']);
@@ -963,7 +974,7 @@ class apache
 						&& isset($row_diroptions['options_cgi'])
 						&& $row_diroptions['options_cgi'] == '1')
 					{
-						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch'."\n";
+						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch +FollowSysLinks'."\n";
 					} else {
 						$this->diroptions_data[$diroptions_filename].= "\n";
 					}
@@ -980,7 +991,7 @@ class apache
 						&& isset($row_diroptions['options_cgi'])
 						&& $row_diroptions['options_cgi'] == '1')
 					{
-						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch'."\n";
+						$this->diroptions_data[$diroptions_filename].= ' ExecCGI -MultiViews +SymLinksIfOwnerMatch +FollowSysLinks'."\n";
 					} else {
 						$this->diroptions_data[$diroptions_filename].= "\n";
 					}
